@@ -2,12 +2,11 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-04-16 14:38:22
-@LastEditTime: 2020-04-25 22:53:42
+@LastEditTime: 2020-05-06 20:30:57
 @LastEditors: ChenXiaolei
 @Description: 
 """
 import base64
-import binascii
 from Crypto.Cipher import AES
 
 
@@ -16,26 +15,37 @@ class CryptoHelper:
     @description: 加密帮助类
     """
     @classmethod
-    def md5_encrypt(self, source, salt=""):
+    def md5_encrypt(self, source, salt="", encoding="utf-8"):
         """
         @description: md5加密，支持加盐算法
         @param source: 需加密的字符串
         @param salt: 加盐算法参数值
+        @param encoding: 字符串编码
         @return: md5加密后的字符串
         @last_editors: ChenXiaolei
         """
-        if not source.strip():
+        if not isinstance(source, str) or not isinstance(salt, str):
+            return ""
+        return self.md5_encrypt_bytes((source + salt).encode(encoding))
+
+    @classmethod
+    def md5_encrypt_bytes(self, source):
+        """
+        @description: md5字节流加密
+        @param source: 字节流
+        @return: md5加密后的字符串
+        @last_editors: ChenXiaolei
+        """
+        if not isinstance(source, bytes):
             return ""
         import hashlib
         encrypt = hashlib.md5()
-        encrypt.update(
-            (source + salt).encode('utf-8')
-        )  # 参数必须是byte类型，否则报Unicode-objects must be encoded before hashing错误
+        encrypt.update(source)
         md5value = encrypt.hexdigest()
         return md5value
 
     @classmethod
-    def md5_encrypt_int(self, source, salt=""):
+    def md5_encrypt_int(self, source, salt="", encoding="utf-8"):
         """
         @description: md5加密，返回数值
         @param source: 需加密的字符串
@@ -43,7 +53,7 @@ class CryptoHelper:
         @return: md5加密后的数值
         @last_editors: ChenXiaolei
         """
-        md5_16 = self._convert_md5(self.md5_encrypt(source, salt))
+        md5_16 = self._convert_md5(self.md5_encrypt(source, salt, encoding))
         hash_code_start = int.from_bytes(md5_16[0:8],
                                          byteorder='little',
                                          signed=True)
@@ -72,7 +82,23 @@ class CryptoHelper:
         return result
 
     @classmethod
-    def base64_encode(self, source):
+    def sha1_encrypt(self, source, encoding="utf-8"):
+        """
+        @description: sha1加密
+        @param source: 需加密的字符串
+        @return: sha1加密后的字符串
+        @last_editors: ChenXiaolei
+        """
+        from hashlib import sha1
+        sha1_sign = sha1()
+        if isinstance(source, str):
+            sha1_sign.update(source.encode(encoding))
+        elif isinstance(source, bytes):
+            sha1_sign.update(source)
+        return sha1_sign.hexdigest()
+
+    @classmethod
+    def base64_encode(self, source, encoding="utf-8"):
         """
         @description: base64加密
         @param source: 需加密的字符串
@@ -82,7 +108,7 @@ class CryptoHelper:
         if not source.strip():
             return ""
         import base64
-        encode_string = base64.b64encode(source.encode(encoding='utf-8'))
+        encode_string = base64.b64encode(source.encode(encoding=encoding))
         return encode_string
 
     @classmethod
@@ -100,35 +126,55 @@ class CryptoHelper:
         return decode_string
 
     @classmethod
-    def aes_encrypt(self, data, password):
+    def _aes_pad(self, text, encoding="utf-8"):
         """
-        @description: AES加密,ECB & PKCS7
-        @param {type} 
-        @return: 
+        @description: 填充函数，使被加密数据的字节码长度是block_size的整数倍
+        @param text: 填充字符串
+        @return: 填充后的字符串
         @last_editors: ChenXiaolei
         """
-        if isinstance(password, str):
-            password = password.encode('utf8')
-
-        bs = AES.block_size
-        pad = lambda s: s + (bs - len(s) % bs) * chr(bs - len(s) % bs)
-        cipher = AES.new(password, AES.MODE_ECB)
-        data = cipher.encrypt(pad(data).encode('utf8'))
-        encrypt_data = binascii.b2a_hex(data)  # 输出hex
-        encrypt_data = base64.b64encode(data)  # 输出Base64格式
-        return encrypt_data.decode('utf8')
+        length = AES.block_size
+        count = len(text.encode(encoding))
+        add = length - (count % length)
+        entext = text + (chr(add) * add)
+        return entext
 
     @classmethod
-    def aes_decrypt(self, decrData, password):
+    def aes_encrypt(self, source, password, encoding="utf-8"):
         """
-        @description: 
-        @param {type} 
-        @return: 
+        @description: AES加密,ECB & PKCS7
+        @param source: 待加密字符串
+        @param password: 密钥 必须为16位或32位
+        @return: 加密后的字符串
         @last_editors: ChenXiaolei
         """
         if isinstance(password, str):
-            password = password.encode('utf8')
+            password = password.encode(encoding)
 
-        cipher = AES.new(password, AES.MODE_ECB)
-        plain_text = cipher.decrypt(binascii.a2b_hex(decrData))
-        return plain_text.decode('utf8').rstrip('\0')
+        aes = AES.new(password, AES.MODE_ECB)  # 初始化AES,ECB模式的实例
+
+        resource = aes.encrypt(self._aes_pad(
+            source, encoding).encode(encoding))
+        result = str(base64.b64encode(resource), encoding=encoding)
+        return result
+
+    @classmethod
+    def aes_decrypt(self, source, password, encoding="utf-8"):
+        """
+        @description: AES解密,ECB & PKCS7
+        @param source: 待解密字符串
+        @param password: 密钥 必须为16位或32位
+        @return: 解密后的明文
+        @last_editors: ChenXiaolei
+        """
+        if isinstance(password, str):
+            password = password.encode(encoding)
+
+        aes = AES.new(password, AES.MODE_ECB)  # 初始化AES,ECB模式的实例
+
+        # 截断函数，去除填充的字符
+        def unpad(date): return date[0:-ord(date[-1])]
+
+        resource = base64.decodebytes(source.encode(encoding))
+        result = aes.decrypt(resource).decode(encoding)
+        return unpad(result)
