@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-04-16 14:38:22
-@LastEditTime: 2020-04-26 09:50:49
+@LastEditTime: 2020-05-14 11:23:49
 @LastEditors: ChenXiaolei
 @Description: json 帮助类
 """
@@ -22,6 +22,6 @@ class JsonEncoder(json.JSONEncoder):
         elif isinstance(obj, datetime.date):
             return obj.strftime("%Y-%m-%d")
         elif isinstance(obj, bytes):
-            return ord(obj)
+            return obj.decode()
         else:
             return json.JSONEncoder.default(self, obj)
\ No newline at end of file
