@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-03-06 23:17:54
-@LastEditTime: 2020-04-27 16:49:26
+@LastEditTime: 2020-05-13 20:02:41
 @LastEditors: ChenXiaolei
 @Description: Handler基础类
 """
@@ -22,7 +22,7 @@ class BaseApiHandler(BaseHandler):
         @description: 初始化
         @last_editors: ChenXiaolei
         """
-        super(BaseHandler, self).__init__(*argc, **argkw)
+        super(BaseApiHandler, self).__init__(*argc, **argkw)
 
     def write_error(self, status_code, **kwargs):
         """
@@ -32,9 +32,9 @@ class BaseApiHandler(BaseHandler):
         self.logger_error.exception('error_info:')
         return self.reponse_json_error()
 
-    def prepare(self):
+    def prepare_ext(self):
         """
-        @description: 置于任何请求方法前被调用
+        @description: 置于任何请求方法前被调用扩展
         @last_editors: ChenXiaolei
         """
         pass
