@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-03-06 23:17:54
-@LastEditTime: 2020-04-25 23:55:32
+@LastEditTime: 2020-05-14 11:27:24
 @LastEditors: ChenXiaolei
 @Description: Handler基础类
 """
@@ -67,7 +67,39 @@ class BaseHandler(tornado.web.RequestHandler):
         await asyncio.get_event_loop().run_in_executor(self.executor,
                                                        self.options_async)
 
-    # 通用handle页面数据返回
+    def prepare(self, *argc, **argkw):
+        """
+        @description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
+        @last_editors: ChenXiaolei
+        """
+        http_request = dict(
+            request_time=TimeHelper.get_now_format_time(),
+            expend_time=self.request.request_time(),
+            response_time=TimeHelper.get_now_format_time(),
+            request_ip=self.get_remote_ip(),
+            method=self.request.method,
+            url=self.request.uri,
+            request_params=self.request.arguments,
+            response_code=self.get_status(),
+        )
+        
+        http_request_json = json.dumps(http_request,cls=JsonEncoder)
+        
+        http_log = config.get_value("http_log")
+        if http_log and http_log==True:
+            self.logger_info.info(http_request_json)
+        else:
+            print('\033[33m' + http_request_json + '\033[0m')
+
+        self.prepare_ext()
+    
+    def prepare_ext(self):
+        """
+        @description: 置于任何请求方法前被调用扩展
+        @last_editors: ChenXiaolei
+        """
+        pass
+
     def render(self, template_name, **template_vars):
         """
         @description: 渲染html源码
@@ -79,6 +111,40 @@ class BaseHandler(tornado.web.RequestHandler):
         html = self.render_string(template_name, **template_vars)
         self.write(html)
 
+    def request_body_to_entity(self, model_entity):
+        """
+        @description: 表单数据对应到实体对象
+        @param model_entity: 数据模型类
+        @return: 装载model_entity 装载成功True 失败False
+        @last_editors: ChenXiaolei
+        """
+        field_list = model_entity.get_field_list()
+        for field_str in field_list:
+            try:
+                if str(field_str).lower() in ["id"]:
+                    continue
+                if field_str in self.request.arguments:
+                    field_val = self.get_argument(field_str)
+                    if field_val is not None:
+                        setattr(model_entity, field_str, self.html_clean(field_val))
+            except Exception as exp:
+                return False
+        return True
+
+    def request_body_to_dict(self):
+        """
+        @description: body参数转字典
+        @return: 参数字典
+        @last_editors: ChenXiaolei
+        """
+        dict_body = {}
+        if self.request.body:
+            dict_str = str.split(CodingHelper.url_decode(self.request.body.decode("unicode_escape'")), "&")
+            for item in dict_str:
+                kv = str.split(item, "=")
+                dict_body[kv[0]] = kv[1]
+        return dict_body
+
     def check_xsrf_cookie(self):
         """
         @description: 过滤受_xsrf影响的post请求 通过获取_xsrf|X-Xsrftoken|X-Csrftoken判断
@@ -145,14 +211,16 @@ class BaseHandler(tornado.web.RequestHandler):
 
     def get_param(self, param_name, default=""):
         """
-        @description: 二次封装获取参数，经过html注入过滤
+        @description: 二次封装获取参数
         @param param_name: 参数名
         @param default: 如果无此参数，则返回默认值
         @return: 参数值
         @last_editors: ChenXiaolei
         """
         param_ret = self.get_argument(param_name, default)
-        return self.html_clean(param_ret)
+        if param_ret == "":
+            param_ret = default
+        return param_ret
 
     def get_remote_ip(self):
         """
@@ -241,15 +309,15 @@ class BaseHandler(tornado.web.RequestHandler):
         self.redirect(url, permanent, status)
 
 
-def filter_check_params(must_params, optional_params=None):
+def filter_check_params(must_params=None, optional_params=None):
     """
     @description: 参数过滤装饰器 仅限handler使用,
                   提供参数的检查及获取参数功能
                   装饰器使用方法:
-                  @param_filter("param_a","param_b","param_c","param_d")  或
-                  @param_filter(["param_a","param_b"],["param_c","param_d"])
+                  @filter_check_params("param_a","param_b","param_c","param_d")  或
+                  @filter_check_params(["param_a","param_b"],["param_c","param_d"])
                   参数获取方法:
-                  self.request_parms[param_key]
+                  self.request_params[param_key]
     @param must_params: 必须传递的参数集合
     @param optional_params: 可选传递的参数集合
     @last_editors: ChenXiaolei
@@ -259,26 +327,27 @@ def filter_check_params(must_params, optional_params=None):
             if not must_params and not optional_params:
                 self.reponse_json_error_params()
                 return
-            self.request_parms = {}
+            self.request_params = {}
             if type(must_params) == str:
                 must_array = must_params.split(",")
             if optional_params and type(optional_params) == str:
                 optional_array = optional_params.split(",")
 
-            for param in must_array:
-                value = self.get_param(param)
-                if not value or value == "":
-                    self.reponse_json_error_params()
-                    return
-                self.request_parms[param] = value
+            if must_params and len(must_array) > 0:
+                for param in must_array:
+                    value = self.get_param(param)
+                    if not value or value == "":
+                        self.reponse_json_error_params()
+                        return
+                    self.request_params[param] = value
 
-            if not optional_array and len(optional_array) > 0:
+            if optional_params and len(optional_array) > 0:
                 for param in optional_array:
                     value = self.get_param(param)
                     if value and value != "":
-                        self.request_parms[param] = value
+                        self.request_params[param] = value
             return handler(self, **args)
 
         return wrapper
 
-    return check_params
\ No newline at end of file
+    return check_params
